Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\comm\__init__.py: 75%

# Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\comm\__init__.py : 75%

## 12 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Copyright (c) 2019-2020 ETH Zurich, SIS ID and HVL D-ITET

2#

3"""Communication protocols subpackage."""

4

5 from .base import ( # noqa: F401

6 CommunicationProtocol,

7 NullCommunicationProtocol,

8)

9

10 try:

11 from .labjack_ljm import ( # noqa: F401

12 LJMCommunication,

13 LJMCommunicationConfig,

14 LJMCommunicationError,

15 )

16 except (ImportError, ModuleNotFoundError):

17 import warnings

18

19 warnings.warn("To use libtiepie library install hvl with command "

20 "`pip install hvl_ccb[tiepie]`.")

21 from .modbus_tcp import ( # noqa: F401

22 ModbusTcpCommunication,

23 ModbusTcpConnectionFailedException,

24 ModbusTcpCommunicationConfig,

25)

26 from .opc import ( # noqa: F401

27 OpcUaCommunication,

28 OpcUaCommunicationConfig,

29 OpcUaCommunicationIOError,

30 OpcUaCommunicationTimeoutError,

31 OpcUaSubHandler,

32)

33 from .telnet import ( # noqa: F401

34 TelnetCommunication,

35 TelnetCommunicationConfig,

36 TelnetError,

37)

38 from .serial import ( # noqa: F401

39 SerialCommunication,

40 SerialCommunicationConfig,

41 SerialCommunicationIOError,

42)

43 from .visa import ( # noqa: F401

44 VisaCommunication,

45 VisaCommunicationError,

46 VisaCommunicationConfig,

47)